# pac_bayes_toolbox

A toolbox algorithm for PAC-Bayesian theory

## Installation

```bash
$ pip install pac_bayes_toolbox
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`pac_bayes_toolbox` was created by Mehdi Hennequin. It is licensed under the terms of the MIT license.

## Credits

